#R code for drawing Figure 6 in Hasegawa et al Scientific Data paper 
#Fig. 6. Adaptation potential, defined as the difference between yield impacts with and without adaptation in projected impacts.
#Author: Hitomi Wakatsuki

library(ggplot2)
library(dplyr)
library(EnvStats)
library(openxlsx)

#Read datasheet
data<-read.xlsx("Projected_impacts_datasheet_11242021.xlsx", sheet=2)

#Extracting data
Ref<-data$Ref.No
Crop <-data$Crop
RCP<- data$Climate.scenario
Timeslice<-factor(data$Time.slice,levels =c("NF","MC", "EC"))
Region<-factor(data$Region, levels = c("Africa","Asia","Australasia","Central and South America","Europe","North America","Global"))
TempAvg<-data$`Current.Average.Temperature.()`
Adaptation_type<-factor(data$Adaptation.type,levels = c("Combined","Cultivar","Fertiliser","Planting date","Tillage","Irrigation","Soil organic matter management","Others"))
DeltaT<-data$Local.delta.T.from.2005
Adaptation_potential<-data$`Adaptation.potential_(%)`
Fertiliser <-data$Fertiliser
Cultivar<-data$Cultivar
PlantT<-data$Planting.time
Tillage <-data$Tillage
Irrigation<-data$Irrigation
Others<-data$Others
Soil_organic<-data$Soil.organic.matter.management



DATA<-data.frame(Ref, Crop,RCP,Timeslice,Region,TempAvg,Adaptation_potential,Adaptation_type,DeltaT)
DATA$Adaptation_type <-factor(DATA$Adaptation_type, levels = c("Combined","Cultivar","Fertiliser","Planting date","Tillage","Irrigation","Soil organic matter management","Others"))

#Selecting RCP & Timeslice 
RCPDATA<-filter(DATA,RCP == "RCP2.6"| RCP == "RCP4.5"| RCP =="RCP8.5")
RCPDATAECMC<-filter(RCPDATA, Timeslice == "EC"|Timeslice == "MC")
RCPDATAECMC$Timeslice = factor(RCPDATAECMC$Timeslice, levels = c("MC","EC"))

#Lables 
my.lables = c("Africa","Asia","Australasia","Central and \nSouth America","Europe","North America","Global")
adaptation.lables = c("Combined", "Cultivar", "Fertiliser", "Planting date","Tillage", "Irrigation","Soil organic matter\nmanagement","Others")


## Fig6_(a) 
dev.new(1)
ggplot(RCPDATAECMC, aes(x = Adaptation_type, y = Adaptation_potential, fill = RCP)) + geom_boxplot(outlier.alpha = 0.1)+
  theme_bw()+
  theme(axis.text.x = element_text(size = 14,angle = 90,vjust = 0.25, hjust = 1)) +
  theme(axis.text.y = element_text(size = 14))+
  theme(axis.title = element_text(size = 14))+
  scale_x_discrete(labels= adaptation.lables)+
  geom_abline(intercept = 0, slope = 0, color = "blue", size = 0.5)+
  ggtitle("")+
  ylab("Adaptation potential (%)")+
  xlab("")+ 
  stat_n_text(y.pos = 50, size = 3.2)+
  coord_cartesian(ylim = c(-25,75))+
  scale_fill_manual(values = c("#A6CEE3","#33A02C","#FB9A99"))+
  facet_grid(.~Timeslice)+
  theme(strip.text.y = element_text(size=14,face="bold"),
        strip.text.x = element_text(size = 14, face ="bold"))
ggsave(filename = "Figure6_(a).tiff", dpi = 100, width = 7.8, height = 5)

#Fig6_(b)
dev.new(2)
ggplot(RCPDATAECMC, aes(x = Region, y = Adaptation_potential, fill = RCP)) + geom_boxplot(outlier.alpha = 0.1)+
  theme_bw()+
  theme(axis.text.x = element_text(size = 14,angle = 90,vjust = 0.25, hjust = 1)) +
  theme(axis.text.y = element_text(size = 14))+
  theme(axis.title = element_text(size = 14))+
  scale_x_discrete(labels= my.lables)+
  geom_abline(intercept = 0, slope = 0, color = "blue", size = 0.5)+
  ggtitle("")+
  ylab("Adaptation potential (%)")+
  xlab("")+ 
  stat_n_text(y.pos = 60,size = 3.2)+
  coord_cartesian(ylim = c(-25,75))+
  scale_fill_manual(values = c("#A6CEE3","#33A02C","#FB9A99"))+
   facet_grid(.~Timeslice)+
  theme(strip.text.y = element_text(size=14,face="bold"),
        strip.text.x = element_text(size = 14, face ="bold"))
ggsave(filename = "Figure6_(b).tiff", dpi = 100, width = 7.8, height = 5)
